@@ -41,6 +41,8 @@
 
 #define KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KWIDGETSADDONS_NO_DEPRECATED) && !defined(KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54700
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x57100
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x54700
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KWIDGETSADDONS_DEPRECATED
-#  define KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -131,57 +133,8 @@
 #else
 #  define KWIDGETSADDONS_DEPRECATED_VERSION_5_65(text)
 #endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54800
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_72(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_72(text)
-#endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54d00
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_77(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_77(text)
-#endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_78(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_78(text)
-#endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55500
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_85(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_85(text)
-#endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55600
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text)
-#endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x56100
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_97(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_97(text)
-#endif
-
-#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x56400
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_100(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_100(text)
-#endif
 #define KWIDGETSADDONS_DEPRECATED_VERSION_5(minor, text)      KWIDGETSADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text)
-#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KWIDGETSADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KWIDGETSADDONS_EXPORT_H */
